==> nextcloud-14.0.13.zip: nextcloud/apps/serverinfo/l10n/gl.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "A información da CPU non está dispoñíbel",
    "Load average" : "Carga media",
    "Last minute" : "Último minuto",
    "Memory info not available" : "A información da memoria non está dispoñíbel",
    "Total" : "Total",
    "Current usage" : "Uso actual",
    "Users" : "Usuarios",
    "Groups" : "Grupos",
    "Links" : "Ligazóns",
    "Mails" : "Correos",
    "Federated sent" : "Federados enviados",
    "Federated received" : "Federados recibidos",
    "Talk conversations" : "Conversas co Talk",
    "24 hours" : "24 horas",
    "1 hour" : "1 hora",
    "5 mins" : "5 minutos",
    "Copy" : "Copiar",
    "Copied!" : "Copiado!",
    "Not supported!" : "Non admitido!",
    "Press ⌘-C to copy." : "Prema ⌘-C para copiar.",
    "Press Ctrl-C to copy." : "Prema Ctrl-C para copiar.",
    "System" : "Sistema",
    "Monitoring" : "Seguimento",
    "Monitoring app with useful server information" : "Aplicativo de seguimento con información útil do servidor",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Fornece información útil do servidor, como a carga da CPU, o uso da memoria RAM, o uso do disco, o número de usuarios, etc.",
    "Operating System" : "Sistema operativo",
    "CPU" : "CPU",
    "Memory" : "Memoria",
    "Server time" : "Hora do servidor",
    "Uptime" : "Tempo de actividade",
    "Time Servers" : "Servidores de hora",
    "Load" : "Carga",
    "Disk" : "Disco",
    "Mount" : "Montaxe",
    "Filesystem" : "Sistema de ficheiros",
    "Size" : "Tamaño",
    "Available" : "Dispoñíbel",
    "Used" : "Usado",
    "You will get a notification once one of your disks is nearly full." : "Recibirá unha notificación cando un dos seus discos estea case completo.",
    "Files:" : "Ficheiros:",
    "Storages:" : "Almacenamentos:",
    "Free Space:" : "Espazo libre:",
    "Network" : "Rede",
    "Hostname" : "Nome de máquina",
    "DNS" : "DNS",
    "Gateway" : "Pasarela",
    "Status" : "Estado",
    "Speed" : "Velocidade",
    "MAC" : "MAC",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Active users" : "Usuarios activos",
    "Total users:" : "Total de usuarios:",
    "Shares" : "Comparticións",
    "PHP" : "PHP",
    "Version:" : "Versión:",
    "Memory Limit:" : "Límite de memoria:",
    "Max Execution Time:" : "Tempo máximo de execución:",
    "Upload max size:" : "Tamaño máximo de envío:",
    "Database" : "Base de datos",
    "Type:" : "Tipo:",
    "Size:" : "Tamaño:",
    "External monitoring tool" : "Ferramenta externa de supervisión",
    "You can connect an external monitoring tool by using this end point:" : "Pode conectar unha ferramenta externa de seguimento usando este punto final:",
    "Did you know?" : "Sabía vostede?",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON format!" : "Engadindo «?format=json» na fin do URL devolve o resultado en formato JSON!",
    "Last 24 hours" : "Últimas 24 horas",
    "Last 1 hour" : "Última hora",
    "Last 5 mins" : "Últimos 5 minutos",
    "CPU load" : "Carga da CPU",
    "Memory usage" : "Uso de memoria",
    "Storage" : "Almacenamento",
    "Users:" : "Usuarios:",
    "Nextcloud" : "Nextcloud",
    "Apps installed:" : "Aplicativos instalados:",
    "Apps updates available:" : "Actualizacións dispoñíbeis de aplicativos:"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.7.zip: nextcloud/apps/serverinfo/l10n/gl.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "A información da CPU non está dispoñíbel",
    "Load average" : "Carga media",
    "Last minute" : "Último minuto",
    "Memory info not available" : "A información da memoria non está dispoñíbel",
    "Total" : "Total",
    "Current usage" : "Uso actual",
    "Users" : "Usuarios",
    "Groups" : "Grupos",
    "Links" : "Ligazóns",
    "Mails" : "Correos",
    "Federated sent" : "Federados enviados",
    "Federated received" : "Federados recibidos",
    "Talk conversations" : "Conversas co Talk",
    "Last 24 hours" : "Últimas 24 horas",
    "Last 1 hour" : "Última hora",
    "Last 5 mins" : "Últimos 5 minutos",
    "Copy" : "Copiar",
    "Copied!" : "Copiado!",
    "Not supported!" : "Non admitido!",
    "Press ⌘-C to copy." : "Prema ⌘-C para copiar.",
    "Press Ctrl-C to copy." : "Prema Ctrl-C para copiar.",
    "Monitoring" : "Seguimento",
    "Monitoring app with useful server information" : "Aplicativo de seguimento con información útil do servidor",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Fornece información útil do servidor, como a carga da CPU, o uso da memoria RAM, o uso do disco, o número de usuarios, etc.",
    "CPU load" : "Carga da CPU",
    "Memory usage" : "Uso de memoria",
    "Active users" : "Usuarios activos",
    "Shares" : "Comparticións",
    "Storage" : "Almacenamento",
    "Users:" : "Usuarios:",
    "Files:" : "Ficheiros:",
    "Storages:" : "Almacenamentos:",
    "Free Space:" : "Espazo libre:",
    "Nextcloud" : "Nextcloud",
    "Version:" : "Versión:",
    "Apps installed:" : "Aplicativos instalados:",
    "Apps updates available:" : "Actualizacións dispoñíbeis de aplicativos:",
    "PHP" : "PHP",
    "Memory Limit:" : "Límite de memoria:",
    "Max Execution Time:" : "Tempo máximo de execución:",
    "Upload max size:" : "Tamaño máximo de envío:",
    "Database" : "Base de datos",
    "Type:" : "Tipo:",
    "Size:" : "Tamaño:",
    "External monitoring tool" : "Ferramenta externa de supervisión",
    "You can connect an external monitoring tool by using this end point:" : "Pode conectar unha ferramenta externa de seguimento usando este punto final:",
    "Did you know?" : "Sabía vostede?",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON format!" : "Engadindo «?format=json» na fin do URL devolve o resultado en formato JSON!"
},
"nplurals=2; plural=(n != 1);");
